<?xml version='1.0'?>
<!-- Comienzo de la hoja de Estilo -->
<xsl:stylesheet xmlns:xsl='http://www.w3.org/1999/XSL/Transform' version='1.0'>  
<!-- Tipo del fichero de salida -->
<xsl:output encoding="ISO-8859-1" method="text" />

<!-- Begin LatexDocument -->
<xsl:template match="Documento">

<!-- Header -->
<xsl:text>
%Plantilla XSLT para obtener documentos basados en LaTeX
%Creado por Jose Mariscal Prieto bajo las condiciones de la licencia GNU optimizado para TeX para UNIX
\documentclass[spanish,12pt,oneside]{article}</xsl:text>
<!-- Propiedades del Texto -->
<xsl:text>

%Compatibilidad con los acentos no necesario \'i
\usepackage[latin1]{inputenc}
\usepackage{babel}
\usepackage{enumerate}
% leftmargin
\oddsidemargin 0in
%text width
\textwidth 6.75in
%margin from top
\topmargin 0in
%height
\textheight 8.5in
\parskip 2ex
</xsl:text>
<!-- Propiedades del Texto -->

<!-- Cuerpo del documento latex -->
<xsl:apply-templates select="node()"/>
</xsl:template>
<!-- Fin del documento LaTex -->


<!-- Principio del Documento -->
<!-- LatexBody -->
<xsl:template match="Curriculum">
<xsl:text>
\begin{document} 
</xsl:text>
<xsl:apply-templates select="node()"/>
<xsl:text>
\end{document}
</xsl:text>
</xsl:template>
<!-- LatexBody -->




<!-- PARTES DEL CUERPO DE LATEX -->
<!-- title -->
<xsl:template match="titulo">
<xsl:text>
\title{</xsl:text><xsl:value-of select="@titulo"/><xsl:text>}</xsl:text>
<xsl:apply-templates select="node()"/>
<xsl:text>
\maketitle
</xsl:text>
</xsl:template>
<!-- title -->

<!-- author -->
<xsl:template match="autor">
<xsl:text>
\author{</xsl:text><xsl:value-of select="@nombre"/><xsl:text>}
</xsl:text>
<xsl:apply-templates select="node()"/>
</xsl:template>
<!-- author -->

<!-- section -->
<xsl:template match="seccion">
<xsl:text>
\section{</xsl:text><xsl:value-of select="@titulo"/><xsl:text>}</xsl:text>
<xsl:apply-templates select="node()"/>
</xsl:template>
<!-- section -->

<!-- Enumeraciones -->
<xsl:template match="dato">
<xsl:text>
\item </xsl:text><xsl:apply-templates select="node()"/>
</xsl:template>
<!-- Gestion del tipo item -->

<!-- itemize -->
<xsl:template match="elementos">
<xsl:text>
\begin{itemize}</xsl:text>
<xsl:apply-templates select="node()"/>
<xsl:text>
\end{itemize}</xsl:text>
</xsl:template>
<!-- itemize -->





<!-- procesamiento del text() -->
<xsl:template match="text()">
<xsl:variable name="S">
<xsl:value-of select="normalize-space()" />
</xsl:variable>

<xsl:if test="string-length($S)>0">

<xsl:call-template name="CaracteresLatex">

<xsl:with-param name="i" select="string-length($S)"/>
<xsl:with-param name="l" select="string-length($S)"/>

</xsl:call-template>
</xsl:if>

</xsl:template>
<!-- procesamiento del text() -->


<!-- Caracteres Especiales de LaTeX -->
<xsl:template name="CaracteresLatex">
<xsl:param name="i"/>
<xsl:param name="l"/>

<xsl:variable name="SS">
<xsl:value-of select="substring(normalize-space(),$l - $i + 1,1)" />
</xsl:variable>

<xsl:if test="$i > 0">

<xsl:choose>
 <!-- Otros Caracteres raros1-->
  <xsl:when test="$SS = '$'">
 <xsl:text>\$</xsl:text>
 </xsl:when>
  <xsl:when test="$SS = '('">
 <xsl:text>\(</xsl:text>
 </xsl:when>
  <xsl:when test="$SS = ')'">
 <xsl:text>\)</xsl:text>
 </xsl:when>
 <xsl:when test="$SS = '|'">
 <xsl:text>$|$</xsl:text>
 </xsl:when>
 <xsl:when test="$SS = '_'">
 <xsl:text>\_</xsl:text>
 </xsl:when>
 <!-- Otros Caracteres raros1-->
 <!-- Otros Caracteres raros2-->
 <xsl:when test="$SS = '^'">
 <xsl:text>\verb'^'</xsl:text>
 </xsl:when>
  <xsl:when test="$SS = '~'">
 <xsl:text>\verb'~'</xsl:text>
 </xsl:when>
 <xsl:when test="$SS = ''">
 <xsl:text>\verb'^'</xsl:text>
 </xsl:when>
 <!-- Otros Caracteres raros2-->
 <xsl:when test="$SS = 'ç'">
 <xsl:text>\c{c}</xsl:text>
 </xsl:when>
 <xsl:when test="$SS = 'ô'">
 <xsl:text>\^{o}</xsl:text>
 </xsl:when>
 <xsl:when test="$SS = 'ù'">
 <xsl:text>\`{u}</xsl:text>
 </xsl:when>
 <xsl:when test="$SS = 'û'">
 <xsl:text>\^{u}</xsl:text>
 </xsl:when>
  <!-- Otros Caracteres raros-->
 <xsl:otherwise><xsl:value-of select="$SS"/></xsl:otherwise>
</xsl:choose>

<xsl:text></xsl:text> 

<xsl:call-template name="CaracteresLatex">
<xsl:with-param name="i" select="$i - 1"/>
<xsl:with-param name="l" select="$l"/>

</xsl:call-template>
</xsl:if>

</xsl:template>
<!-- Caracteres Especiales de LaTeX -->

</xsl:stylesheet>
<!-- End stylesheet -->